<h1 align="center">
  <br>
  <a>pyroSAR</a>
</h1>
<h3 align="center">A Python Framework for Large-Scale SAR Satellite Data Processing</h3>

<p align="center">
  <a href='https://github.com/johntruckenbrodt/pyroSAR/actions/workflows/python-package-conda.yml'>
    <img src='https://github.com/johntruckenbrodt/pyroSAR/actions/workflows/python-package-conda.yml/badge.svg' alt='Travis Status'></a>
  <a href='https://coveralls.io/github/johntruckenbrodt/pyroSAR?branch=main'>
    <img src='https://coveralls.io/repos/github/johntruckenbrodt/pyroSAR/badge.svg?branch=main' alt='Coveralls Status' /></a>
  <a href='https://pyrosar.readthedocs.io/en/latest/?badge=latest'>
    <img src='https://readthedocs.org/projects/pyrosar/badge/?version=latest' alt='Documentation Status' /></a>
  <a href='https://badge.fury.io/py/pyroSAR'>
    <img src='https://badge.fury.io/py/pyroSAR.svg' alt='PIP Status' /></a>
  <a href='https://anaconda.org/conda-forge/pyrosar'>
    <img src='https://img.shields.io/conda/vn/conda-forge/pyrosar.svg' alt='Conda Status' /></a>
</p>

The pyroSAR package aims at providing a complete solution for the scalable organization and processing of SAR satellite data:
* Reading of data from various past and present satellite missions
* Handling of acquisition metadata
* User-friendly access to processing utilities in [SNAP](https://step.esa.int/main/toolboxes/snap/) 
and [GAMMA Remote Sensing](https://www.gamma-rs.ch/) software
* Formatting of the preprocessed data for further analysis
* Export to Data Cube solutions

Head on over to [readthedocs](https://pyrosar.readthedocs.io/en/latest/?badge=latest) for installation instructions,
examples and API reference.
